Installation
============

Install from PyPI:
::
    
    pip install sinto


Install from source:
::

    git clone https://github.com/timoast/sinto.git
    cd sinto
    python setup.py install


Testing
-------

::

    pip install pytest
    pytest